* Encoding: windows-1252.
****************************************************************************************.
* 2007_cross_csv.do
*
* SPSS Command Syntax File
* Release 24.0.0.1
*
* The following syntax transforms the country separated EU-SILC CSV-data (as released by Eurostat)
* into a combined  SPSS-Systemfile and a combined CSV file. Please insert you file paths and file names for each file type separately.
* 
* EU-SILC - Cross 2007
*
* (c) GESIS 2018-06-26
* GESIS - Leibniz Institute for the Social Sciences
* German Microdata Lab 
* Valentina Ponomarenko, Meike Selbach
* https://www.gesis.org/gml/european-microdata/eu-silc/
*
* Contact: valentina.ponomarenko@gesis.org
***************************************************************************************.


set decimal=DOT.

* When using SPSS earlier than V16 you might not use "set unicode"  .

set unicode=OFF.

* The csv files for Greece are not appropriately named. The following command changes the names on the hardrive in order for the macro to work properly.
* The renaming is permanent and needs only to be executed once for every file.
* Change csv_data_path_GR to the path where the csv file for Greece is stored. 

HOST COMMAND =['RENAME "csv_data_path_EL\UDB_cGR07D.csv" UDB_cEL07D.csv'].
HOST COMMAND =['RENAME "csv_data_path_EL\UDB_cGR07H.csv" UDB_cEL07H.csv'].
HOST COMMAND =['RENAME "csv_data_path_EL\UDB_cGR07P.csv" UDB_cEL07P.csv'].
HOST COMMAND =['RENAME "csv_data_path_EL\UDB_cGR07R.csv" UDB_cEL07R.csv'].

*------------------------- Loop to open and convert D-files country files into one csv file -----------------------------------------------------------------------.

*-----------------------------------------------------------------     Start definition macro     ---------------------------------------------------------------.

DEFINE !C2007_nD ().

*--------------------------------------------------------     CONFIGURATION SECTION - Start    ------------------------------------------------------.


*  The following command should contain the complete path where the CSV data files are stored;
*  1) Change CSV_PATH to your file path; (E.g. C:\EU-SILC\Crossectional 2004-2016\);
*  2) But keep path structure as delivered by Eurostat CSV_PATH/COUNTRY/YEAR .

!LET !csv_path ='CSV_PATH'


*  The following command should contain the complete path where the SPSS data files should be stored;
*  Change SPSS_PATH to your file path.

!LET !spss_path ='SPSS_PATH'


* The following command should contain the complete path and name of the CSV files (specify without .csv extension);
* Change CSV_D_FILENAME to your final filename.

!LET !finalfile='SPSS_FILENAME'

*-----------------------------------------------------------  CONFIGURATION SECTION - End      ---------------------------------------------------------.

!LET !csvfiles= 'UDB_cAT UDB_cBE UDB_cCY UDB_cCZ UDB_cDE UDB_cDK UDB_cEE UDB_cEL' 
+ ' UDB_cES UDB_cFI UDB_cFR UDB_cHU UDB_cIE UDB_cIS UDB_cIT UDB_cLT UDB_cLU UDB_cLV' 
+ ' UDB_cNL UDB_cNO UDB_cPL UDB_cPT UDB_cSE UDB_cSI UDB_cSK UDB_cUK'.

!LET !CC= 'AT BE CY CZ DE DK EE EL ES FI FR HU IE IS IT LT LU LV NL NO PL PT SE SI SK UK'.

!DO !i !IN (!CC)

     GET DATA
          /TYPE=TXT
          /FILE=!QUOTE(!CONCAT(!csv_path,!i,'\2007\UDB_c',!i,'07D.csv'))
          /ENCODING='Locale'
          /DELCASE=LINE
          /DELIMITERS=","
          /ARRANGEMENT=DELIMITED
          /FIRSTCASE=2
          /IMPORTCASE=ALL
          /VARIABLES=
   DB010 F4.0
   DB020 A2
   DB030 F3.0
   DB040 A4
   DB040_F F1.0
   DB060 F1.0
   DB060_F F2.0
   DB062 F1.0
   DB062_F F2.0
   DB070 F1.0
   DB070_F F2.0
   DB075 F1.0
   DB075_F F1.0
   DB090 COMMA8.0
   DB090_F F1.0
   DB100 F1.0
   DB100_F F1.0.
         
 SAVE OUTFILE=!QUOTE(!CONCAT(!spss_path,'UDB_c',!i,'07D.sav')).

    !DOEND.


*-------------------------------------------------- Compile and save final file -----------------------------------------------------------------------------------.

    !LET !firstfile=1.
    !DO !filestub !IN (!csvfiles).
      !IF (!firstfile=1) !THEN
          GET FILE=!QUOTE(!CONCAT(!spss_path,!filestub,'07D.sav')).
          !LET !firstfile=0.
       !ELSE
          ADD FILES FILE=* /FILE=!QUOTE(!CONCAT(!spss_path,!filestub,'07D.sav')).
       !IFEND.
       !DOEND.
    SAVE OUTFILE=!QUOTE(!CONCAT(!spss_path,!finalfile,'.sav')).
    SAVE TRANSLATE OUTFILE=!QUOTE(!CONCAT(!spss_path,!finalfile,'.csv'))
    /REPLACE.
   
*--------------------------------------------------------Delete single country files -------------------------------------------------------------------------------.

!DO !filestub !IN (!csvfiles).
        ERASE FILE=!QUOTE(!CONCAT(!spss_path,!filestub,'07D.sav')).
!DOEND.

!ENDDEFINE.

!C2007_nD.



*------------------------- Loop to open and convert H-files country files into one csv file -----------------------------------------------------------------------.

*-----------------------------------------------------------------     Start definition macro     ---------------------------------------------------------------.

DEFINE !C2007_nH ().

*--------------------------------------------------------     CONFIGURATION SECTION - Start    ------------------------------------------------------.


*  The following command should contain the complete path where the CSV data files are stored;
*  1) Change CSV_PATH to your file path; (E.g. C:\EU-SILC\Crossectional 2004-2016\);
*  2) But keep path structure as delivered by Eurostat CSV_PATH/COUNTRY/YEAR .

!LET !csv_path ='CSV_PATH'


*  The following command should contain the complete path where the SPSS data files should be stored;
*  Change SPSS_PATH to your file path.

!LET !spss_path ='SPSS_PATH'


* The following command should contain the complete path and name of the CSV files (specify without .csv extension);
* Change CSV_D_FILENAME to your final filename.

!LET !finalfile='SPSS_FILENAME'

*-----------------------------------------------------------  CONFIGURATION SECTION - End      ---------------------------------------------------------.

!LET !csvfiles= 'UDB_cAT UDB_cBE UDB_cCY UDB_cCZ UDB_cDE UDB_cDK UDB_cEE UDB_cEL' 
+ ' UDB_cES UDB_cFI UDB_cFR UDB_cHU UDB_cIE UDB_cIS UDB_cIT UDB_cLT UDB_cLU UDB_cLV' 
+ ' UDB_cNL UDB_cNO UDB_cPL UDB_cPT UDB_cSE UDB_cSI UDB_cSK UDB_cUK'.

!LET !CC= 'AT BE CY CZ DE DK EE EL ES FI FR HU IE IS IT LT LU LV NL NO PL PT SE SI SK UK'.

!DO !i !IN (!CC)

   GET DATA
          /TYPE=TXT
          /FILE=!QUOTE(!CONCAT(!csv_path,!i,'\2007\UDB_c',!i,'07H.csv'))
          /ENCODING='Locale'
          /DELCASE=LINE
          /DELIMITERS=","
          /ARRANGEMENT=DELIMITED
          /FIRSTCASE=2
          /IMPORTCASE=ALL
          /VARIABLES=
  HB010 F4.0
  HB020 A2
  HB030 F3.0
  HB050 F1.0
  HB050_F F1.0
  HB060 F4.0
  HB060_F F1.0
  HB070 F5.0
  HB070_F F1.0
  HB080 F5.0
  HB080_F F1.0
  HB090 F5.0
  HB090_F F2.0
  HB100 F2.0
  HB100_F F1.0
  HY010 COMMA9.0
  HY010_F F1.0
  HY010_I COMMA7.0
  HY020 COMMA9.0
  HY020_F F1.0
  HY020_I COMMA8.0
  HY022 COMMA9.0
  HY022_F F1.0
  HY022_I COMMA8.0
  HY023 COMMA9.0
  HY023_F F1.0
  HY023_I COMMA8.0
  HY025 COMMA7.0
  HY025_F F1.0
  HY030N COMMA8.0
  HY030N_F F1.0
  HY040N COMMA8.0
  HY040N_F F2.0
  HY040N_I COMMA9.0
  HY050N COMMA8.0
  HY050N_F F2.0
  HY050N_I COMMA9.0
  HY060N COMMA8.0
  HY060N_F F2.0
  HY060N_I COMMA9.0
  HY070N COMMA7.0
  HY070N_F F2.0
  HY070N_I COMMA7.0
  HY080N COMMA7.0
  HY080N_F F2.0
  HY080N_I COMMA9.0
  HY090N COMMA8.0
  HY090N_F F2.0
  HY090N_I COMMA8.0
  HY100N COMMA8.0
  HY100N_F F1.0
  HY100N_I COMMA9.0
  HY110N COMMA8.0
  HY110N_F F2.0
  HY110N_I COMMA9.0
  HY120N COMMA8.0
  HY120N_F F1.0
  HY120N_I COMMA9.0
  HY130N COMMA8.0
  HY130N_F F2.0
  HY130N_I COMMA9.0
  HY140N COMMA8.0
  HY140N_F F2.0
  HY140N_I COMMA9.0
  HY145N COMMA8.0
  HY145N_F F1.0
  HY145N_I COMMA9.0
  HY030G COMMA8.0
  HY030G_F F1.0
  HY040G COMMA8.0
  HY040G_F F1.0
  HY040G_I COMMA9.0
  HY050G COMMA8.0
  HY050G_F F1.0
  HY050G_I COMMA9.0
  HY060G COMMA8.0
  HY060G_F F1.0
  HY060G_I COMMA9.0
  HY070G COMMA8.0
  HY070G_F F1.0
  HY070G_I COMMA9.0
  HY080G COMMA8.0
  HY080G_F F1.0
  HY080G_I COMMA9.0
  HY090G COMMA8.0
  HY090G_F F1.0
  HY090G_I COMMA7.0
  HY100G COMMA8.0
  HY100G_F F1.0
  HY100G_I COMMA9.0
  HY110G COMMA8.0
  HY110G_F F1.0
  HY110G_I COMMA9.0
  HY120G COMMA8.0
  HY120G_F F1.0
  HY120G_I COMMA9.0
  HY130G COMMA8.0
  HY130G_F F1.0
  HY130G_I COMMA9.0
  HY140G COMMA9.0
  HY140G_F F1.0
  HY140G_I COMMA9.0
  HS010 F1.0
  HS010_F F2.0
  HS020 F1.0
  HS020_F F1.0
  HS030 F1.0
  HS030_F F2.0
  HS040 F1.0
  HS040_F F2.0
  HS050 F1.0
  HS050_F F1.0
  HS060 F1.0
  HS060_F F1.0
  HS070 F1.0
  HS070_F F1.0
  HS080 F1.0
  HS080_F F1.0
  HS090 F1.0
  HS090_F F1.0
  HS100 F1.0
  HS100_F F1.0
  HS110 F1.0
  HS110_F F1.0
  HS120 F1.0
  HS120_F F1.0
  HS130 COMMA7.0
  HS130_F F2.0
  HS140 F1.0
  HS140_F F1.0
  HS150 F1.0
  HS150_F F2.0
  HS160 F1.0
  HS160_F F1.0
  HS170 F1.0
  HS170_F F1.0
  HS180 F1.0
  HS180_F F1.0
  HS190 F1.0
  HS190_F F1.0
  HH010 F1.0
  HH010_F F2.0
  HH020 F1.0
  HH020_F F1.0
  HH030 F1.0
  HH030_F F1.0
  HH031 F4.0
  HH031_F F2.0
  HH040 F1.0
  HH040_F F1.0
  HH050 F1.0
  HH050_F F1.0
  HH060 COMMA6.0
  HH060_F F2.0
  HH061 COMMA7.0
  HH061_F F2.0
  HH070 COMMA7.0
  HH070_F F2.0
  HH080 F1.0
  HH080_F F1.0
  HH090 F1.0
  HH090_F F1.0
  MH010 F1.0
  MH010_F F1.0
  MH020 F1.0
  MH020_F F1.0
  MH030 F1.0
  MH030_F F1.0
  MH040 F1.0
  MH040_F F1.0
  MH050 F1.0
  MH050_F F1.0
  MH060 F1.0
  MH060_F F1.0
  MH070 F1.0
  MH070_F F1.0
  MH080 F1.0
  MH080_F F2.0
  MH090 F1.0
  MH090_F F2.0
  MH100 F1.0
  MH100_F F2.0
  MH110 F1.0
  MH110_F F2.0
  MH120 F1.0
  MH120_F F2.0
  MH130 F1.0
  MH130_F F2.0
  MH140 F1.0
  MH140_F F2.0
  MH150 F1.0
  MH150_F F1.0
  MH160 F1.0
  MH160_F F2.0
  HX040 F1.0
  HX050 COMMA4.0
  HX090 COMMA9.0
  HX080 F1.0
  HX060 F2.0
  HX070 F1.0
  HX020 F1.0
  HX010 COMMA9.0
  HY081N COMMA8.0
  HY131N COMMA8.0
  HY081G COMMA8.0
  HY131G COMMA8.0.

 SAVE OUTFILE=!QUOTE(!CONCAT(!spss_path,'UDB_c',!i,'07H.sav')).

    !DOEND.


*-------------------------------------------------- Compile and save final file -----------------------------------------------------------------------------------.

    !LET !firstfile=1.
    !DO !filestub !IN (!csvfiles).
      !IF (!firstfile=1) !THEN
          GET FILE=!QUOTE(!CONCAT(!spss_path,!filestub,'07H.sav')).
          !LET !firstfile=0.
       !ELSE
          ADD FILES FILE=* /FILE=!QUOTE(!CONCAT(!spss_path,!filestub,'07H.sav')).
       !IFEND.
       !DOEND.
    SAVE OUTFILE=!QUOTE(!CONCAT(!spss_path,!finalfile,'.sav')).
    SAVE TRANSLATE OUTFILE=!QUOTE(!CONCAT(!spss_path,!finalfile,'.csv'))
    /REPLACE.
   
*--------------------------------------------------------Delete single country files -------------------------------------------------------------------------------.

!DO !filestub !IN (!csvfiles).
        ERASE FILE=!QUOTE(!CONCAT(!spss_path,!filestub,'07H.sav')).
!DOEND.

!ENDDEFINE.

!C2007_nH.



*------------------------- Loop to open and convert P-files country files into one csv file -----------------------------------------------------------------------.

*-----------------------------------------------------------------     Start definition macro     ---------------------------------------------------------------.

DEFINE !C2007_nP ().

*--------------------------------------------------------     CONFIGURATION SECTION - Start    ------------------------------------------------------.


*  The following command should contain the complete path where the CSV data files are stored;
*  1) Change CSV_PATH to your file path; (E.g. C:\EU-SILC\Crossectional 2004-2016\);
*  2) But keep path structure as delivered by Eurostat CSV_PATH/COUNTRY/YEAR .

!LET !csv_path ='CSV_PATH'


*  The following command should contain the complete path where the SPSS data files should be stored;
*  Change SPSS_PATH to your file path.

!LET !spss_path ='SPSS_PATH'


* The following command should contain the complete path and name of the CSV files (specify without .csv extension);
* Change CSV_D_FILENAME to your final filename.

!LET !finalfile='SPSS_FILENAME'

*-----------------------------------------------------------  CONFIGURATION SECTION - End      ---------------------------------------------------------.

!LET !csvfiles= 'UDB_cAT UDB_cBE UDB_cCY UDB_cCZ UDB_cDE UDB_cDK UDB_cEE UDB_cEL' 
+ ' UDB_cES UDB_cFI UDB_cFR UDB_cHU UDB_cIE UDB_cIS UDB_cIT UDB_cLT UDB_cLU UDB_cLV' 
+ ' UDB_cNL UDB_cNO UDB_cPL UDB_cPT UDB_cSE UDB_cSI UDB_cSK UDB_cUK'.

!LET !CC= 'AT BE CY CZ DE DK EE EL ES FI FR HU IE IS IT LT LU LV NL NO PL PT SE SI SK UK'.

!DO !i !IN (!CC)

     GET DATA
          /TYPE=TXT
          /FILE=!QUOTE(!CONCAT(!csv_path,!i,'\2007\UDB_c',!i,'07P.csv'))
          /ENCODING='Locale'
          /DELCASE=LINE
          /DELIMITERS=','
          /ARRANGEMENT=DELIMITED
          /FIRSTCASE=2
          /IMPORTCASE=ALL
          /VARIABLES=
    PB010 F4.0
    PB020 A2
    PB030 F5.0
    PB040 COMMA8.0
    PB040_F F1.0
    PB060 COMMA8.0
    PB060_F F1.0
    PB100 F1.0
    PB100_F F1.0
    PB110 F4.0
    PB110_F F1.0
    PB120 F2.0
    PB120_F F1.0
    PB130 F1.0
    PB130_F F1.0
    PB140 F4.0
    PB140_F F1.0
    PB150 F1.0
    PB150_F F1.0
    PB160 F5.0
    PB160_F F2.0
    PB170 F5.0
    PB170_F F2.0
    PB180 F5.0
    PB180_F F2.0
    PB190 F1.0
    PB190_F F1.0
    PB200 F1.0
    PB200_F F1.0
    PB210 A3
    PB210_F F1.0
    PB220A A3
    PB220A_F F1.0
    PE010 F1.0
    PE010_F F1.0
    PE020 F1.0
    PE020_F F2.0
    PE030 F4.0
    PE030_F F1.0
    PE040 F1.0
    PE040_F F1.0
    PL030 F1.0
    PL030_F F1.0
    PL035 F1.0
    PL035_F F1.0
    PL015 F1.0
    PL015_F F2.0
    PL020 F1.0
    PL020_F F2.0
    PL025 F1.0
    PL025_F F2.0
    PL040 F1.0
    PL040_F F2.0
    PL050 F2.0
    PL050_F F2.0
    PL060 F2.0
    PL060_F F2.0
    PL070 F2.0
    PL070_F F1.0
    PL072 F2.0
    PL072_F F1.0
    PL080 F2.0
    PL080_F F1.0
    PL085 F2.0
    PL085_F F1.0
    PL087 F2.0
    PL087_F F1.0
    PL090 F2.0
    PL090_F F1.0
    PL100 F2.0
    PL100_F F2.0
    PL110_F F2.0
    PL120 F1.0
    PL120_F F2.0
    PL130 F2.0
    PL130_F F2.0
    PL140 F1.0
    PL140_F F2.0
    PL150 F1.0
    PL150_F F2.0
    PL160 F1.0
    PL160_F F2.0
    PL170 F1.0
    PL170_F F2.0
    PL180 F2.0
    PL180_F F2.0
    PL190 F2.0
    PL190_F F2.0
    PL200 F2.0
    PL200_F F2.0
    PL210A F1.0
    PL210A_F F1.0
    PL210B F1.0
    PL210B_F F1.0
    PL210C F1.0
    PL210C_F F1.0
    PL210D F1.0
    PL210D_F F1.0
    PL210E F1.0
    PL210E_F F1.0
    PL210F F1.0
    PL210F_F F1.0
    PL210G F1.0
    PL210G_F F1.0
    PL210H F1.0
    PL210H_F F1.0
    PL210I F1.0
    PL210I_F F1.0
    PL210J F1.0
    PL210J_F F1.0
    PL210K F1.0
    PL210K_F F1.0
    PL210L F1.0
    PL210L_F F1.0
    PH010 F1.0
    PH010_F F1.0
    PH020 F1.0
    PH020_F F1.0
    PH030 F1.0
    PH030_F F1.0
    PH040 F1.0
    PH040_F F1.0
    PH050 F1.0
    PH050_F F2.0
    PH060 F1.0
    PH060_F F1.0
    PH070 F1.0
    PH070_F F2.0
    PY010N COMMA8.0
    PY010N_F F2.0
    PY010N_I COMMA9.0
    PY020N COMMA4.2
    PY020N_F F2.0
    PY020N_I COMMA9.0
    PY021N COMMA4.0
    PY021N_F F2.0
    PY035N COMMA7.0
    PY035N_F F1.0
    PY035N_I COMMA9.0
    PY050N COMMA8.0
    PY050N_F F2.0
    PY050N_I COMMA9.0
    PY070N COMMA7.0
    PY070N_F F2.0
    PY070N_I COMMA9.0
    PY080N COMMA4.0
    PY080N_F F1.0
    PY080N_I COMMA9.0
    PY090N COMMA7.0
    PY090N_F F2.0
    PY090N_I COMMA9.0
    PY100N COMMA8.0
    PY100N_F F2.0
    PY100N_I COMMA9.0
    PY110N COMMA8.0
    PY110N_F F2.0
    PY110N_I COMMA9.0
    PY120N COMMA7.0
    PY120N_F F2.0
    PY120N_I COMMA9.0
    PY130N COMMA8.0
    PY130N_F F2.0
    PY130N_I COMMA9.0
    PY140N COMMA7.0
    PY140N_F F2.0
    PY140N_I COMMA9.0
    PY010G COMMA8.0
    PY010G_F F1.0
    PY010G_I COMMA9.0
    PY020G COMMA4.2
    PY020G_F F2.0
    PY020G_I COMMA9.0
    PY021G COMMA4.0
    PY021G_F F2.0
    PY030G COMMA8.0
    PY030G_F F1.0
    PY035G COMMA7.0
    PY035G_F F1.0
    PY035G_I COMMA9.0
    PY050G COMMA8.0
    PY050G_F F1.0
    PY050G_I COMMA9.0
    PY070G COMMA7.0
    PY070G_F F1.0
    PY070G_I COMMA9.0
    PY080G COMMA4.0
    PY080G_F F1.0
    PY080G_I COMMA9.0
    PY090G COMMA7.0
    PY090G_F F1.0
    PY090G_I COMMA9.0
    PY100G COMMA8.0
    PY100G_F F1.0
    PY100G_I COMMA9.0
    PY110G COMMA8.0
    PY110G_F F1.0
    PY110G_I COMMA9.0
    PY120G COMMA7.0
    PY120G_F F1.0
    PY120G_I COMMA9.0
    PY130G COMMA8.0
    PY130G_F F1.0
    PY130G_I COMMA9.0
    PY140G COMMA7.0
    PY140G_F F1.0
    PY140G_I COMMA9.0
    PY200G COMMA7.0
    PY200G_F F2.0
    PY200G_I COMMA9.0
    PX030 F3.0
    PX040 F1.0
    PY021N_I COMMA9.0
    PY021G_I COMMA9.0
    PY030G_I COMMA9.0
    PX020 F2.0
    PX050 F1.0
    PX010 COMMA9.0
    PY031G COMMA9.0
    PL110 A5.

 SAVE OUTFILE=!QUOTE(!CONCAT(!spss_path,'UDB_c',!i,'07P.sav')).

    !DOEND.


*-------------------------------------------------- Compile and save final file -----------------------------------------------------------------------------------.

    !LET !firstfile=1.
    !DO !filestub !IN (!csvfiles).
      !IF (!firstfile=1) !THEN
          GET FILE=!QUOTE(!CONCAT(!spss_path,!filestub,'07P.sav')).
          !LET !firstfile=0.
       !ELSE
          ADD FILES FILE=* /FILE=!QUOTE(!CONCAT(!spss_path,!filestub,'07P.sav')).
       !IFEND.
       !DOEND.
    SAVE OUTFILE=!QUOTE(!CONCAT(!spss_path,!finalfile,'.sav')).
    SAVE TRANSLATE OUTFILE=!QUOTE(!CONCAT(!spss_path,!finalfile,'.csv'))
    /REPLACE.
   
*--------------------------------------------------------Delete single country files -------------------------------------------------------------------------------.

!DO !filestub !IN (!csvfiles).
        ERASE FILE=!QUOTE(!CONCAT(!spss_path,!filestub,'07P.sav')).
!DOEND.

!ENDDEFINE.

!C2007_nP.



*------------------------- Loop to open and convert R-files country files into one csv file -----------------------------------------------------------------------.

*-----------------------------------------------------------------     Start definition macro     ---------------------------------------------------------------.

DEFINE !C2007_nR ().

*--------------------------------------------------------     CONFIGURATION SECTION - Start    ------------------------------------------------------.


*  The following command should contain the complete path where the CSV data files are stored;
*  1) Change CSV_PATH to your file path; (E.g. C:\EU-SILC\Crossectional 2004-2016\);
*  2) But keep path structure as delivered by Eurostat CSV_PATH/COUNTRY/YEAR .

!LET !csv_path ='CSV_PATH'


*  The following command should contain the complete path where the SPSS data files should be stored;
*  Change SPSS_PATH to your file path.

!LET !spss_path ='SPSS_PATH'


* The following command should contain the complete path and name of the CSV files (specify without .csv extension);
* Change CSV_D_FILENAME to your final filename.

!LET !finalfile='SPSS_FILENAME'

*-----------------------------------------------------------  CONFIGURATION SECTION - End      ---------------------------------------------------------.

!LET !csvfiles= 'UDB_cAT UDB_cBE UDB_cCY UDB_cCZ UDB_cDE UDB_cDK UDB_cEE UDB_cEL' 
+ ' UDB_cES UDB_cFI UDB_cFR UDB_cHU UDB_cIE UDB_cIS UDB_cIT UDB_cLT UDB_cLU UDB_cLV' 
+ ' UDB_cNL UDB_cNO UDB_cPL UDB_cPT UDB_cSE UDB_cSI UDB_cSK UDB_cUK'.

!LET !CC= 'AT BE CY CZ DE DK EE EL ES FI FR HU IE IS IT LT LU LV NL NO PL PT SE SI SK UK'.

!DO !i !IN (!CC)

      GET DATA
          /TYPE=TXT
          /FILE=!QUOTE(!CONCAT(!csv_path,!i,'\2007\UDB_c',!i,'07R.csv'))
          /ENCODING='Locale'
          /DELCASE=LINE
          /DELIMITERS=","
          /ARRANGEMENT=DELIMITED
          /FIRSTCASE=2
          /IMPORTCASE=ALL
          /VARIABLES=
  RB010 F4.0
  RB020 A2
  RB030 F5.0
  RB050 COMMA8.0
  RB050_F F1.0
  RB070 F1.0
  RB070_F F1.0
  RB080 F4.0
  RB080_F F1.0
  RB090 F1.0
  RB090_F F1.0
  RB200 F1.0
  RB200_F F1.0
  RB210 F1.0
  RB210_F F1.0
  RB220 F5.0
  RB220_F F2.0
  RB230 F5.0
  RB230_F F2.0
  RB240 F5.0
  RB240_F F2.0
  RB245 F1.0
  RB245_F F1.0
  RB250 F2.0
  RB250_F F2.0
  RB260 F1.0
  RB260_F F2.0
  RB270 F5.0
  RB270_F F2.0
  RL010 F2.0
  RL010_F F2.0
  RL020 F2.0
  RL020_F F2.0
  RL030 F2.0
  RL030_F F2.0
  RL040 F2.0
  RL040_F F2.0
  RL050 F1.0
  RL050_F F2.0
  RL060 F1.0
  RL060_F F2.0
  RL070 comma8.0
  RL070_F F2.0
  RX030 F3.0
  RX020 F2.0
  RX010 F2.0.
     
 SAVE OUTFILE=!QUOTE(!CONCAT(!spss_path,'UDB_c',!i,'07R.sav')).

    !DOEND.


*-------------------------------------------------- Compile and save final file -----------------------------------------------------------------------------------.

    !LET !firstfile=1.
    !DO !filestub !IN (!csvfiles).
      !IF (!firstfile=1) !THEN
          GET FILE=!QUOTE(!CONCAT(!spss_path,!filestub,'07R.sav')).
          !LET !firstfile=0.
       !ELSE
          ADD FILES FILE=* /FILE=!QUOTE(!CONCAT(!spss_path,!filestub,'07R.sav')).
       !IFEND.
       !DOEND.
    SAVE OUTFILE=!QUOTE(!CONCAT(!spss_path,!finalfile,'.sav')).
    SAVE TRANSLATE OUTFILE=!QUOTE(!CONCAT(!spss_path,!finalfile,'.csv'))
    /REPLACE.
   
*--------------------------------------------------------Delete single country files -------------------------------------------------------------------------------.

!DO !filestub !IN (!csvfiles).
        ERASE FILE=!QUOTE(!CONCAT(!spss_path,!filestub,'07R.sav')).
!DOEND.

!ENDDEFINE.

!C2007_nR.

